summaryrefslogtreecommitdiffstats
path: root/lib/koproperty/property.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /lib/koproperty/property.cpp
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'lib/koproperty/property.cpp')
-rw-r--r--lib/koproperty/property.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/lib/koproperty/property.cpp b/lib/koproperty/property.cpp
index 49ca2b6c..6c4fa246 100644
--- a/lib/koproperty/property.cpp
+++ b/lib/koproperty/property.cpp
@@ -43,7 +43,7 @@ class PropertyPrivate
: caption(0), listData(0), changed(false), storable(true),
readOnly(false), visible(true),
autosync(-1), custom(0), useCustomProperty(true),
- sets(0), parent(0), tqchildren(0), relatedProperties(0),
+ sets(0), parent(0), children(0), relatedProperties(0),
sortingKey(0)
{
}
@@ -63,7 +63,7 @@ class PropertyPrivate
delete caption;
caption = 0;
delete listData;
- delete tqchildren;
+ delete children;
delete relatedProperties;
delete custom;
delete sets;
@@ -99,7 +99,7 @@ class PropertyPrivate
// TQValueList<Set*> sets;
Property *parent;
- TQValueList<Property*> *tqchildren;
+ TQValueList<Property*> *children;
//! list of properties with the same name (when intersecting buffers)
TQValueList<Property*> *relatedProperties;
@@ -564,9 +564,9 @@ Property::operator= (const Property &property)
delete d->listData;
d->listData = 0;
}
- if(d->tqchildren) {
- delete d->tqchildren;
- d->tqchildren = 0;
+ if(d->children) {
+ delete d->children;
+ d->children = 0;
}
if(d->relatedProperties) {
delete d->relatedProperties;
@@ -594,16 +594,16 @@ Property::operator= (const Property &property)
}
if(property.d->custom) {
d->custom = FactoryManager::self()->createCustomProperty(this);
// updates all tqchildren value, using CustomProperty
setValue(property.value());
}
else {
d->value = property.d->value;
- if(property.d->tqchildren) {
- // no CustomProperty (should never happen), simply copy all tqchildren
- d->tqchildren = new TQValueList<Property*>();
- TQValueList<Property*>::ConstIterator endIt = property.d->tqchildren->constEnd();
- for(TQValueList<Property*>::ConstIterator it = property.d->tqchildren->constBegin(); it != endIt; ++it) {
+ if(property.d->children) {
+ // no CustomProperty (should never happen), simply copy all children
+ d->children = new TQValueList<Property*>();
+ TQValueList<Property*>::ConstIterator endIt = property.d->children->constEnd();
+ for(TQValueList<Property*>::ConstIterator it = property.d->children->constBegin(); it != endIt; ++it) {
Property *child = new Property( *(*it) );
addChild(child);
}
@@ -614,7 +614,7 @@ Property::operator= (const Property &property)
d->relatedProperties = new TQValueList<Property*>( *(property.d->relatedProperties));
}
// update these later because they may have been changed when creating tqchildren
d->oldValue = property.d->oldValue;
d->changed = property.d->changed;
d->sortingKey = property.d->sortingKey;
@@ -631,16 +631,16 @@ Property::operator ==(const Property &prop) const
/////////////////////////////////////////////////////////////////
const TQValueList<Property*>*
-Property::tqchildren() const
+Property::children() const
{
- return d->tqchildren;
+ return d->children;
}
Property*
Property::child(const TQCString &name)
{
- TQValueList<Property*>::ConstIterator endIt = d->tqchildren->constEnd();
- for(TQValueList<Property*>::ConstIterator it = d->tqchildren->constBegin(); it != endIt; ++it) {
+ TQValueList<Property*>::ConstIterator endIt = d->children->constEnd();
+ for(TQValueList<Property*>::ConstIterator it = d->children->constBegin(); it != endIt; ++it) {
if((*it)->name() == name)
return *it;
}
@@ -659,11 +659,11 @@ Property::addChild(Property *prop)
if (!prop)
return;
- if(!d->tqchildren || tqFind( d->tqchildren->begin(), d->tqchildren->end(), prop) == d->tqchildren->end()) { // not in our list
- if(!d->tqchildren)
- d->tqchildren = new TQValueList<Property*>();
- d->tqchildren->append(prop);
- prop->setSortingKey(d->tqchildren->count());
+ if(!d->children || tqFind( d->children->begin(), d->children->end(), prop) == d->children->end()) { // not in our list
+ if(!d->children)
+ d->children = new TQValueList<Property*>();
+ d->children->append(prop);
+ prop->setSortingKey(d->children->count());
prop->d->parent = this;
}
else {
@@ -594,16 +594,16 @@ Property::operator= (const Property &property)
if(property.d->custom) {
d->custom = FactoryManager::self()->createCustomProperty(this);
- // updates all tqchildren value, using CustomProperty
+ // updates all children value, using CustomProperty
setValue(property.value());
}
@@ -614,7 +614,7 @@ Property::operator= (const Property &property)
d->relatedProperties = new TQValueList<Property*>( *(property.d->relatedProperties));
}
- // update these later because they may have been changed when creating tqchildren
+ // update these later because they may have been changed when creating children
d->oldValue = property.d->oldValue;
d->changed = property.d->changed;